==> zio-aws-elasticache_3-5.17.147.1-sources.jar: zio/aws/elasticache/model/DestinationDetails.scala <==
package zio.aws.elasticache.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DestinationDetails(
    cloudWatchLogsDetails: Option[
      zio.aws.elasticache.model.CloudWatchLogsDestinationDetails
    ] = None,
    kinesisFirehoseDetails: Option[
      zio.aws.elasticache.model.KinesisFirehoseDestinationDetails
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.DestinationDetails = {
    import DestinationDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.DestinationDetails
      .builder()
      .optionallyWith(
        cloudWatchLogsDetails.map(value => value.buildAwsValue())
      )(_.cloudWatchLogsDetails)
      .optionallyWith(
        kinesisFirehoseDetails.map(value => value.buildAwsValue())
      )(_.kinesisFirehoseDetails)
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.DestinationDetails.ReadOnly =
    zio.aws.elasticache.model.DestinationDetails.wrap(buildAwsValue())
}
object DestinationDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.DestinationDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.DestinationDetails =
      zio.aws.elasticache.model.DestinationDetails(
        cloudWatchLogsDetails.map(value => value.asEditable),
        kinesisFirehoseDetails.map(value => value.asEditable)
      )
    def cloudWatchLogsDetails: Option[
      zio.aws.elasticache.model.CloudWatchLogsDestinationDetails.ReadOnly
    ]
    def kinesisFirehoseDetails: Option[
      zio.aws.elasticache.model.KinesisFirehoseDestinationDetails.ReadOnly
    ]
    def getCloudWatchLogsDetails: ZIO[
      Any,
      AwsError,
      zio.aws.elasticache.model.CloudWatchLogsDestinationDetails.ReadOnly
    ] =
      AwsError.unwrapOptionField("cloudWatchLogsDetails", cloudWatchLogsDetails)
    def getKinesisFirehoseDetails: ZIO[
      Any,
      AwsError,
      zio.aws.elasticache.model.KinesisFirehoseDestinationDetails.ReadOnly
    ] = AwsError.unwrapOptionField(
      "kinesisFirehoseDetails",
      kinesisFirehoseDetails
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.DestinationDetails
  ) extends zio.aws.elasticache.model.DestinationDetails.ReadOnly {
    override val cloudWatchLogsDetails: Option[
      zio.aws.elasticache.model.CloudWatchLogsDestinationDetails.ReadOnly
    ] = scala
      .Option(impl.cloudWatchLogsDetails())
      .map(value =>
        zio.aws.elasticache.model.CloudWatchLogsDestinationDetails.wrap(value)
      )
    override val kinesisFirehoseDetails: Option[
      zio.aws.elasticache.model.KinesisFirehoseDestinationDetails.ReadOnly
    ] = scala
      .Option(impl.kinesisFirehoseDetails())
      .map(value =>
        zio.aws.elasticache.model.KinesisFirehoseDestinationDetails.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.DestinationDetails
  ): zio.aws.elasticache.model.DestinationDetails.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticache_3-5.17.201.2-sources.jar: zio/aws/elasticache/model/DestinationDetails.scala <==
package zio.aws.elasticache.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DestinationDetails(
    cloudWatchLogsDetails: Optional[
      zio.aws.elasticache.model.CloudWatchLogsDestinationDetails
    ] = Optional.Absent,
    kinesisFirehoseDetails: Optional[
      zio.aws.elasticache.model.KinesisFirehoseDestinationDetails
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.DestinationDetails = {
    import DestinationDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.DestinationDetails
      .builder()
      .optionallyWith(
        cloudWatchLogsDetails.map(value => value.buildAwsValue())
      )(_.cloudWatchLogsDetails)
      .optionallyWith(
        kinesisFirehoseDetails.map(value => value.buildAwsValue())
      )(_.kinesisFirehoseDetails)
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.DestinationDetails.ReadOnly =
    zio.aws.elasticache.model.DestinationDetails.wrap(buildAwsValue())
}
object DestinationDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.DestinationDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.DestinationDetails =
      zio.aws.elasticache.model.DestinationDetails(
        cloudWatchLogsDetails.map(value => value.asEditable),
        kinesisFirehoseDetails.map(value => value.asEditable)
      )
    def cloudWatchLogsDetails: Optional[
      zio.aws.elasticache.model.CloudWatchLogsDestinationDetails.ReadOnly
    ]
    def kinesisFirehoseDetails: Optional[
      zio.aws.elasticache.model.KinesisFirehoseDestinationDetails.ReadOnly
    ]
    def getCloudWatchLogsDetails: ZIO[
      Any,
      AwsError,
      zio.aws.elasticache.model.CloudWatchLogsDestinationDetails.ReadOnly
    ] =
      AwsError.unwrapOptionField("cloudWatchLogsDetails", cloudWatchLogsDetails)
    def getKinesisFirehoseDetails: ZIO[
      Any,
      AwsError,
      zio.aws.elasticache.model.KinesisFirehoseDestinationDetails.ReadOnly
    ] = AwsError.unwrapOptionField(
      "kinesisFirehoseDetails",
      kinesisFirehoseDetails
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.DestinationDetails
  ) extends zio.aws.elasticache.model.DestinationDetails.ReadOnly {
    override val cloudWatchLogsDetails: Optional[
      zio.aws.elasticache.model.CloudWatchLogsDestinationDetails.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.cloudWatchLogsDetails())
      .map(value =>
        zio.aws.elasticache.model.CloudWatchLogsDestinationDetails.wrap(value)
      )
    override val kinesisFirehoseDetails: Optional[
      zio.aws.elasticache.model.KinesisFirehoseDestinationDetails.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.kinesisFirehoseDetails())
      .map(value =>
        zio.aws.elasticache.model.KinesisFirehoseDestinationDetails.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.DestinationDetails
  ): zio.aws.elasticache.model.DestinationDetails.ReadOnly = new Wrapper(impl)
}
